dispose method
For testing / shutdown. Closes the state stream and disposes the underlying runtime.
Implementation
Future<void> dispose() async {
await _runtime.dispose();
await _state.close();
}
For testing / shutdown. Closes the state stream and disposes the underlying runtime.
Future<void> dispose() async {
await _runtime.dispose();
await _state.close();
}