SyniChatFinal class

The final parsed response. Always emitted exactly once at the end of a successful stream.

Inheritance

Constructors

SyniChatFinal(SyniChatResponse response)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
response → SyniChatResponse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited