underlyingErrorCode property
Stable code classifying the failure behind a fallback (INVALID_JSON,
SCHEMA, TIMEOUT, …), else null.
Implementation
final String? underlyingErrorCode;
Stable code classifying the failure behind a fallback (INVALID_JSON,
SCHEMA, TIMEOUT, …), else null.
final String? underlyingErrorCode;