authHeaders property

Future<Map<String, String>> Function(String method, String url) authHeaders
final

Per-request auth-header provider. Given the HTTP method and the absolute request url, returns the headers to attach — e.g. {'X-Synheart-Proof': '<jws>'} for device-attestation auth.

It is request-aware because an X-Synheart-Proof is signed over the method and URL and so cannot be a static token. Return an empty map when no credential is available (the cloud rejects unauthenticated requests unless it is in test mode with DISABLE_CHAT_AUTH=true).

Implementation

final Future<Map<String, String>> Function(String method, String url)
    authHeaders;