SyniGenerationProfile class
Per-turn inference controls. Omitted values retain the runtime preset.
Constructors
Properties
- dryMultiplier → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokens → int?
-
final
- minP → double?
-
final
- penaltyFreq → double?
-
final
- penaltyRepeat → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int?
-
final
- temperature → double?
-
final
- topK → int?
-
final
- topP → double?
-
final
- ttftTimeoutMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited