SyniInstallFailed class

Install failed. reason is human-readable; cause is the underlying exception when available.

Inheritance

Constructors

SyniInstallFailed({required String reason, Object? cause})
const

Properties

cause Object?
final
hashCode int
The hash code for this object.
no setterinherited
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited