SyniInstalling class

Install in progress. progress is in [0.0, 1.0]; stage explains which sub-step is running.

Inheritance

Constructors

SyniInstalling({required SyniInstallStage stage, required double progress})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage SyniInstallStage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited