SyniPreset enum

Performance preset (mirrors syni_preset_t in c_api.h).

Inheritance
Available extensions

Values

keyboard → const SyniPreset
const SyniPreset(0)
coach → const SyniPreset
const SyniPreset(1)
chat → const SyniPreset
const SyniPreset(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int v) → SyniPreset

Constants

values → const List<SyniPreset>
A constant List of the values in this enum, in order of their declaration.