SyniRuntimeMessage class

One prior dialogue turn. System authority is carried separately by SyniRuntimeRequest.system so dialogue can never silently become policy.

Constructors

SyniRuntimeMessage({required SyniRuntimeMessageRole role, required String content})
const

Properties

content → String
final
hashCode → int
The hash code for this object.
no setterinherited
role → SyniRuntimeMessageRole
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited