SyniRuntimeProvenance class

Constructors

SyniRuntimeProvenance({required String backend, required String accelerator, required String runtimeVersion, String? modelId})
const
SyniRuntimeProvenance.fromMap(Map map)
factory

Properties

accelerator → String
final
backend → String
final
hashCode → int
The hash code for this object.
no setterinherited
modelId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersion → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited