retryable property
Whether the underlying failure behind a fallback was transient. False when isFallback is false.
Implementation
final bool retryable;
Whether the underlying failure behind a fallback was transient. False when isFallback is false.
final bool retryable;