underlyingErrorCode property
Stable code classifying the underlying failure behind a fallback
(INVALID_JSON, SCHEMA, TIMEOUT, …), when isFallback. Null otherwise.
Implementation
final String? underlyingErrorCode;
Stable code classifying the underlying failure behind a fallback
(INVALID_JSON, SCHEMA, TIMEOUT, …), when isFallback. Null otherwise.
final String? underlyingErrorCode;