SyniRuntimeStreamFinal class

Final accumulated JSON response, emitted exactly once when generation completes. Always the last element of the stream before close.

Inheritance

Constructors

SyniRuntimeStreamFinal(String rawJson)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rawJson → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited