Suggestion class

A single keyboard suggestion.

Used with persona: keyboard.v1

Constructors

Suggestion({required String text, String? label, double? confidence, String? category})
const
Suggestion.fromMap(Map<String, dynamic> map)
factory

Properties

category String?
Optional category or type of suggestion.
final
confidence double?
Confidence score (0.0 to 1.0) if provided.
final
hashCode int
The hash code for this object.
no setterinherited
label String?
Optional display label (if different from text).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The suggested text to insert.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited