SyniResponseMeta class

Metadata about a Syni response.

Constructors

SyniResponseMeta({required String schemaId, required String personaId, String? engine, int? durationMs, bool isFallback = false})
const
SyniResponseMeta.fromMap(Map<String, dynamic> map)
factory

Properties

durationMs int?
Processing duration in milliseconds.
final
engine String?
The engine that processed this request (e.g., "local", "cloud").
final
hashCode int
The hash code for this object.
no setterinherited
isFallback bool
Whether this is a fallback response due to an error.
final
personaId String
The persona ID that handled this request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaId String
The schema ID used for this response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited