SyniCloudConfig class
Properties
appId
→ String
final
Per-request auth-header provider. Given the HTTP method and the
absolute request url, returns the headers to attach — e.g.
{'X-Synheart-Proof': '<jws>'} for device-attestation auth.
final
baseUrl
→ String
Syni cloud base URL, e.g. https://api.synheart.ai or
http://localhost:8093 for dev.
final
deviceId
→ String
final
hashCode
→ int
The hash code for this object.
no setter inherited
orgId
→ String
final
projectId
→ String
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
tenantId
→ String
final
userId
→ String
final
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited