SyniCloudConfig class

Constructors

SyniCloudConfig({required String baseUrl, required Future<String?> authToken(), required String tenantId, required String userId, String projectId = '', String orgId = '', String appId = '', String deviceId = ''})
const

Properties

appId String
final
authToken Future<String?> Function()
Async bearer token provider. Returns null when no token is available (the cloud will fail unauthenticated unless it is in test mode with DISABLE_CHAT_AUTH=true).
final
baseUrl String
syni-service base URL, e.g. https://api.synheart.ai or http://localhost:8093 for dev.
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
orgId String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited