SyniCloudConfig class
Constructors
Properties
- appId → String
-
final
-
authToken
→ Future<
String?> Function() -
Async bearer token provider. Returns
nullwhen no token is available (the cloud will fail unauthenticated unless it is in test mode withDISABLE_CHAT_AUTH=true).final - baseUrl → String
-
syni-servicebase URL, e.g.https://api.synheart.aiorhttp://localhost:8093for dev.final - deviceId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orgId → String
-
final
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tenantId → String
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited