SyniCloudConfig class

Constructors

SyniCloudConfig({required String baseUrl, required Future<Map<String, String>> authHeaders(String method, String url), required String tenantId, required String userId, String projectId = '', String orgId = '', String appId = '', String deviceId = ''})
const

Properties

appId String
final
authHeaders Future<Map<String, String>> Function(String method, String url)
Per-request auth-header provider. Given the HTTP method and the absolute request url, returns the headers to attach — e.g. {'X-Synheart-Proof': '<jws>'} for device-attestation auth.
final
baseUrl String
Syni cloud base URL, e.g. https://api.synheart.ai or http://localhost:8093 for dev.
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
orgId String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited