SyniInstalled class
Successfully installed. The runtime engine has loaded the model and is ready to receive chat calls.
- Inheritance
-
- Object
- SyniInstallState
- SyniInstalled
Constructors
- SyniInstalled({required String personaId, required String modelPath, required String runtimeVersion})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelPath → String
-
final
- personaId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runtimeVersion → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited