SyniTurnResult class
Completed typed turn plus routing and native provenance information.
Constructors
- SyniTurnResult({required String requestId, required SyniTurnBackend backend, required SyniChatResponse response, String? apiVersion, String? finishReason, SyniTurnProvenance? provenance})
-
const
Properties
- apiVersion → String?
-
final
- backend → SyniTurnBackend
-
final
- finishReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- provenance → SyniTurnProvenance?
-
final
- requestId → String
-
final
- response → SyniChatResponse
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited