SyniAttemptDiagnostic class

One generation attempt's failure.

Constructors

SyniAttemptDiagnostic({required int attempt, required String errorCode, required String errorMessage, required int outputLen, required bool repairAttempted})
const
SyniAttemptDiagnostic.fromMap(Map<String, dynamic> m)
factory

Properties

attempt int
final
errorCode String
final
errorMessage String
final
hashCode int
The hash code for this object.
no setterinherited
outputLen int
final
repairAttempted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited