SyniRuntimeCapabilities class
Constructors
-
SyniRuntimeCapabilities({required List<
String> apiVersions, required String backend, required String accelerator, required bool supportsSystemRole, required Set<String> generationControls, required bool supportsStructuredDecoding, required bool supportsStreaming, required bool streamsDisplayText, required bool supportsProvenance, required bool isLegacy}) -
const
- SyniRuntimeCapabilities.fromJson(String json)
-
factory
Properties
- accelerator → String
-
final
-
apiVersions
→ List<
String> -
final
- backend → String
-
final
-
generationControls
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLegacy → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamsDisplayText → bool
-
final
- supportsProvenance → bool
-
final
- supportsStreaming → bool
-
final
- supportsStructuredDecoding → bool
-
final
- supportsSystemRole → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- legacy → const SyniRuntimeCapabilities