SyniRuntimeError class
Thrown when the runtime, model, or inference call fails.
- Implemented types
Constructors
- SyniRuntimeError(String message)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited