SyniRuntimeRequest class
A single inference request.
hsi is an opaque conditioning payload — the runtime's PromptBuilder
reads it. For HSI 1.3 callers should pass the full HSI payload here; for
V1 callers that don't yet have HSI integration, a flat ad-hoc map works
too (Syni currently ignores unknown fields).
Constructors
-
SyniRuntimeRequest({required String instruction, String? apiVersion, String? requestId, Map<
String, dynamic> ? hsi, String? schema, String? system, List<SyniRuntimeMessage> messages = const [], SyniRuntimeGenerationConfig? generation}) -
const
Properties
- apiVersion → String?
-
final
- generation → SyniRuntimeGenerationConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hsi
→ Map<
String, dynamic> ? -
final
- instruction → String
-
final
-
messages
→ List<
SyniRuntimeMessage> -
final
- requestId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → String?
-
final
- system → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited