SyniRuntimeResponse class
Schema-validated response from the runtime.
Constructors
- SyniRuntimeResponse(String rawJson)
- SyniRuntimeResponse.fromJson(String json)
-
factory
Properties
- data → dynamic
-
Parsed top-level map. Field set depends on the persona's response
schema (
chat_response,coach_response,suggestions, …).final - hashCode → int
-
The hash code for this object.
no setterinherited
- rawJson → String
-
Raw JSON string returned by the runtime (already grammar-constrained
and validated against the persona's output schema).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited