SyniRuntimeStreamFinal class
Final accumulated JSON response, emitted exactly once when generation completes. Always the last element of the stream before close.
- Inheritance
-
- Object
- SyniRuntimeStreamChunk
- SyniRuntimeStreamFinal
Constructors
- SyniRuntimeStreamFinal(String rawJson)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited